==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/footer_include.php <==
<?php defined("HELLO") or exit(); ?>
<ul class="navigation-menu">
<?php
if (isset($navi_paging)){
if ($navi_paging === TRUE){
$base_query = $_SERVER['QUERY_STRING'];
$base_query = preg_replace("/&*log=try/u", "", $base_query);
$base_query = preg_replace("/&oauth_token=[^&]+/u", "", $base_query);
$base_query = preg_replace("/&oauth_verifier=[^&]+/u", "", $base_query);
  if ($_GET['page'] != ''){
	  if ($_GET['page'] >= 100){
		  $next_query = preg_replace('/page=[0123456789]{1,3}/u',"page=1",$base_query);
		  $next_url = "http://{$_SERVER["SERVER_NAME"]}{$_SERVER['PHP_SELF']}?$next_query";
		  $next_num = 1;
	  }	else {
			  $next_num = $_GET['page'] + 1;
			  $next_query = preg_replace('/page=[0123456789]{1,3}/u',"page={$next_num}",$base_query);
			  $next_url = "http://" . $_SERVER["SERVER_NAME"] . $_SERVER["PHP_SELF"] . "?" . $next_query;
		  }
  }	elseif ($base_query != ""){
		  $next_num = 2;
		  $next_query = $base_query . "&page=" . $next_num;
		  $next_url = "http://" . $_SERVER["SERVER_NAME"] . $_SERVER["PHP_SELF"] . "?" . $next_query;
  }	else {
		  $next_num = 2;
		  $next_query = "page=" . $next_num;
		  $next_url = "http://" . $_SERVER["SERVER_NAME"] . $_SERVER["PHP_SELF"] . "?" . $next_query;
  }
  if ($next_num == 1){
	  $current_page = 100;
  } else {
	  $current_page = $next_num - 1;
  }
  if ($_GET['page'] != ''){
	  if ($_GET['page'] <= 1){
		  $prev_query = preg_replace('/page=[0123456789]{1,3}/u',"page=100",$base_query);
		  $prev_url = "http://{$_SERVER["SERVER_NAME"]}{$_SERVER['PHP_SELF']}?$prev_query";
		  $prev_num = 100;
	  } else {
		  $prev_num = $_GET['page'] - 1;
		  $prev_query = preg_replace('/page=[0123456789]{1,3}/u',"page={$prev_num}",$base_query);
		  $prev_url = "http://{$_SERVER['SERVER_NAME']}" . $_SERVER["PHP_SELF"] . "?" . $prev_query;
	  }
  } elseif ($base_query != ''){
	  $prev_num = 100;
	  $prev_query = $safequery . '&page=' . $prev_num;
	  $prev_url = "http://{$_SERVER['SERVER_NAME']}" . $_SERVER["PHP_SELF"] . "?" . $prev_query;
  } else {
	  $prev_num = 100;
	  $prev_query = 'page=' . $prev_num;
	  $prev_url = "http://{$_SERVER['SERVER_NAME']}" . $_SERVER["PHP_SELF"] . "?" . $prev_query;
  }
}
if (mb_strlen($next_num) == 1) $next_str = '00'.$next_num;
if (mb_strlen($next_num) == 2) $next_str = '0'.$next_num;
if (mb_strlen($next_num) == 3) $next_str = $next_num;
if (mb_strlen($prev_num) == 1) $prev_str = '00'.$prev_num;
if (mb_strlen($prev_num) == 2) $prev_str = '0'.$prev_num;
if (mb_strlen($prev_num) == 3) $prev_str = $prev_num;
}
?>
<?php
/*if ($_GET['image'] != ''){
	$qimagemode = '?image=' . $_GET['image'];
} else {
	$qimagemode = '';
}*/
if ($entries_mode == 'default'){
	$first = $self_anchor.'?page=1';
} else {
	$first = $self_anchor.'&amp;page=1';
}
$to_entries = './entries.php';
$to_index = './index.php';
$to_keywords = './keywords.php';
if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on'){
  $first = $first.'&amp;image=on';
  $to_entries = $to_entries.'?image=on';
  $to_index = $to_index.'?image=on';
}
if ($navi_paging === TRUE) echo "<li>この頁は " . $current_page . " ページ</li>";

echo "<li>";
if ($navi_paging === TRUE){
  echo "1.<a href=\"{$first}\" class=\"navigation-link\" accesskey=\"1\">最初の頁</a> ";
} else {
  echo "1.&nbsp;-&nbsp;-&nbsp;-&nbsp;- ";
}
echo "2.<a href=\"{$to_entries}\" class=\"navigation-link\" accesskey=\"2\">皆の投稿</a> ";
echo "3.<a href=\"mailto:h@hatena.ne.jp?subject=";
if (isset($_GET['keyword'])){
  echo rawurlencode(rawurldecode($_GET['keyword']));
} elseif (isset($_GET['word'])){
  echo rawurlencode(rawurldecode($_GET['word']));
}
if (isset($_GET['body'])) echo '&amp;body='.rawurlencode(rawurldecode($_GET['body']));
echo "\" class=\"navigation-link\" accesskey=\"3\">メール</a></li>";

echo "<li>";
if ($navi_paging === TRUE){
  $prev_url = htmlspecialchars($prev_url, ENT_QUOTES);
  echo "4.<a href=\"{$prev_url}\" class=\"navigation-link\" accesskey=\"4\" rel=\"nofollow\">前(p{$prev_str})</a> ";
} else {
  echo "4.&nbsp;-&nbsp;-&nbsp;-&nbsp;- ";
}
if ($navi_imaging === TRUE){
  if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on'){
/*	  if (preg_match('/^image=on$/u', $_SERVER['QUERY_STRING'])){
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	  } elseif (isset($_GET['log']) && preg_match('/^log=(on|off)$/u', $_SERVER['QUERY_STRING'])){
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	  } elseif ($_SERVER["QUERY_STRING"] != ""){*/
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '&amp;image=off';
/*	  } else {
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	  }*/
	  echo '5.<a href="' . $self_anchor_invert_imagemode .  '" class="navigation-link" accesskey="5" rel="nofollow">画像省略</a> ';
  } elseif ($_GET['image'] == 'off' || $_SESSION['image'] == 'off' || $_GET['image'] == '' || $_SESSION['image'] == ''){
/*	  if (preg_match('/^image=off$/u', $_SERVER['QUERY_STRING'])){
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	  } elseif (isset($_GET['log']) && preg_match('/^log=(off|on)$/u', $_SERVER['QUERY_STRING'])){
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	  } elseif ($_SERVER["QUERY_STRING"] != ""){*/
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '&amp;image=on';
/*	  } else {
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	  }*/
	  echo '5.<a href="' . $self_anchor_invert_imagemode . '" class="navigation-link" accesskey="5" rel="nofollow">画像表示</a> ';
  }
} else {
  echo "5.&nbsp;-&nbsp;-&nbsp;-&nbsp;- ";
}
if ($navi_paging === TRUE){
  $next_url = htmlspecialchars($next_url, ENT_QUOTES);
  echo "6.<a href=\"{$next_url}\" class=\"navigation-link\" accesskey=\"6\" rel=\"nofollow\">次(p{$next_str})</a></li>";
} else {
  echo "6.&nbsp;-&nbsp;-&nbsp;-&nbsp;- </li>";
}
echo '<li>';
if (isset($entries_mode)){
  if ($entries_mode == 'keyword_timeline'){
// var_dump($entries_mode);
	echo "7.<a href=\"./keywords.php?related=".rawurlencode($_GET['keyword']);
	if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on') echo '&amp;image=on';
	echo "\" class=\"navigation-link\" accesskey=\"7\">関連鍵語</a> ";
  } elseif ($entries_mode == 'user_timeline'){
	echo "7.<a href=\"./keywords.php?user=".$get_user;
	if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on') echo '&amp;image=on';
	echo "\" class=\"navigation-link\" accesskey=\"7\">愛好鍵語</a> ";
  } elseif ($entries_mode == 'friends_timeline'){
	echo "7.<a href=\"./keywords.php?user=".$get_following;
	if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on') echo '&amp;image=on';
	echo "\" class=\"navigation-link\" accesskey=\"7\">愛好鍵語</a> ";
  } else {
	echo '7.<a href="'.$to_keywords;
	if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on') echo '?image=on';
	echo "\" class=\"navigation-link\" accesskey=\"7\">鍵語一覧</a> ";
  }
} else {
  echo '7.<a href="'.$to_keywords;
  if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on') echo '?image=on';
  echo "\" class=\"navigation-link\" accesskey=\"7\">鍵語一覧</a> ";
}
if ($_SESSION['auth'] === TRUE){
	echo "8.<a href=\"./entries.php?following={$_SESSION['hatenaid']}";
	if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on') echo '&amp;image=on';
	echo "\" class=\"navigation-link\" accesskey=\"8\">アンテナ</a> ";
} else {
	echo '8.&nbsp;-&nbsp;-&nbsp;-&nbsp;- ';
}
	echo '9.<a href="'.$to_index.'" class="navigation-link" accesskey="9">トビラ</a>';
echo '</li>';

/*echo '<li>';
if ($_SESSION['auth'] === TRUE){
	echo '[-]<a href="./login.php?log=out';
	if ($_SESSION['image'] == 'on') echo '&amp;image=on';
	echo '" class="navigation-link">ログアウト</a>';
} elseif ($_GET['image'] == 'on'){
	echo '[0]<a href="./login.php?return=' . rawurlencode($self_anchor_with_imagemode) . '&amp;image=on" class="navigation-link" accesskey="0">ログイン</a>';
} else {
	echo '[0]<a href="./login.php?return=' . rawurlencode($self_anchor_with_imagemode) . '" class="navigation-link" accesskey="0">ログイン</a>';
}
echo '</li>'."\n";*/
?>
</ul>
<hr />
<?php echo $footer; ?>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/footer_include.php <==
<?php defined("HELLO") or exit(); ?>
<ul class="navigation-menu">
<?php
if (isset($navi_paging)){
if ($navi_paging === TRUE){
$base_query = $_SERVER['QUERY_STRING'];
$base_query = preg_replace("/&*log=try/u", "", $base_query);
$base_query = preg_replace("/&oauth_token=[^&]+/u", "", $base_query);
$base_query = preg_replace("/&oauth_verifier=[^&]+/u", "", $base_query);
  if (isset($_GET['page']) && $_GET['page'] != ''){
	  if ($_GET['page'] >= 100){
		  $next_query = preg_replace('/page=[0123456789]{1,3}/u',"page=1",$base_query);
		  $next_url = "http://{$_SERVER["SERVER_NAME"]}{$_SERVER['PHP_SELF']}?$next_query";
		  $next_num = 1;
	  }	else {
			  $next_num = $_GET['page'] + 1;
			  $next_query = preg_replace('/page=[0123456789]{1,3}/u',"page={$next_num}",$base_query);
			  $next_url = "http://" . $_SERVER["SERVER_NAME"] . $_SERVER["PHP_SELF"] . "?" . $next_query;
		  }
  }	elseif ($base_query != ""){
		  $next_num = 2;
		  $next_query = $base_query . "&page=" . $next_num;
		  $next_url = "http://" . $_SERVER["SERVER_NAME"] . $_SERVER["PHP_SELF"] . "?" . $next_query;
  }	else {
		  $next_num = 2;
		  $next_query = "page=" . $next_num;
		  $next_url = "http://" . $_SERVER["SERVER_NAME"] . $_SERVER["PHP_SELF"] . "?" . $next_query;
  }
  if ($next_num == 1){
	  $current_page = 100;
  } else {
	  $current_page = $next_num - 1;
  }
  if (isset($_GET['page']) && $_GET['page'] != ''){
	  if ($_GET['page'] <= 1){
		  $prev_query = preg_replace('/page=[0123456789]{1,3}/u',"page=100",$base_query);
		  $prev_url = "http://{$_SERVER["SERVER_NAME"]}{$_SERVER['PHP_SELF']}?$prev_query";
		  $prev_num = 100;
	  } else {
		  $prev_num = $_GET['page'] - 1;
		  $prev_query = preg_replace('/page=[0123456789]{1,3}/u',"page={$prev_num}",$base_query);
		  $prev_url = "http://{$_SERVER['SERVER_NAME']}" . $_SERVER["PHP_SELF"] . "?" . $prev_query;
	  }
  } elseif ($base_query != ''){
	  $prev_num = 100;
	  $prev_query = $safequery . '&page=' . $prev_num;
	  $prev_url = "http://{$_SERVER['SERVER_NAME']}" . $_SERVER["PHP_SELF"] . "?" . $prev_query;
  } else {
	  $prev_num = 100;
	  $prev_query = 'page=' . $prev_num;
	  $prev_url = "http://{$_SERVER['SERVER_NAME']}" . $_SERVER["PHP_SELF"] . "?" . $prev_query;
  }
if (mb_strlen($next_num) == 1) $next_str = '00'.$next_num;
if (mb_strlen($next_num) == 2) $next_str = '0'.$next_num;
if (mb_strlen($next_num) == 3) $next_str = $next_num;
if (mb_strlen($prev_num) == 1) $prev_str = '00'.$prev_num;
if (mb_strlen($prev_num) == 2) $prev_str = '0'.$prev_num;
if (mb_strlen($prev_num) == 3) $prev_str = $prev_num;
}
}
?>
<?php
/*if ($_GET['image'] != ''){
	$qimagemode = '?image=' . $_GET['image'];
} else {
	$qimagemode = '';
}*/
if ((isset($entries_mode) && $entries_mode == 'default') || (isset($list_mode) && $list_mode == 'default')){
	$first = $self_anchor.'?page=1';
} else {
	$first = $self_anchor.'&amp;page=1';
}
$to_entries = './entries.php';
$to_index = './index.php';
$to_keywords = './keywords.php';
if (isset($_GET['image']) && $_GET['image'] == 'on'){
  $first = $first.'&amp;image=on';
  $to_entries = $to_entries.'?image=on';
  $to_index = $to_index.'?image=on';
}
if ($navi_paging === TRUE) echo "<li>この頁は " . $current_page . " ページ</li>";

echo "<li>";
if ($navi_paging === TRUE){
  echo "1.<a href=\"{$first}\" class=\"navigation-link\" accesskey=\"1\">最初の頁</a> ";
} else {
  echo "1.&nbsp;-&nbsp;-&nbsp;-&nbsp;- ";
}
echo "2.<a href=\"{$to_entries}\" class=\"navigation-link\" accesskey=\"2\">皆の投稿</a> ";
echo "3.<a href=\"mailto:h@hatena.ne.jp?subject=";
if (isset($_GET['keyword'])){
  echo rawurlencode(rawurldecode($_GET['keyword']));
} elseif (isset($_GET['word'])){
  echo rawurlencode(rawurldecode($_GET['word']));
}
if (isset($_GET['body'])) echo '&amp;body='.rawurlencode(rawurldecode($_GET['body']));
echo "\" class=\"navigation-link\" accesskey=\"3\">メール</a></li>";

echo "<li>";
if ($navi_paging === TRUE){
  $prev_url = htmlspecialchars($prev_url, ENT_QUOTES);
  echo "4.<a href=\"{$prev_url}\" class=\"navigation-link\" accesskey=\"4\" rel=\"nofollow\">前(p{$prev_str})</a> ";
} else {
  echo "4.&nbsp;-&nbsp;-&nbsp;-&nbsp;- ";
}
if ($navi_imaging === TRUE){
  if ($get_image == 'on'){
/*	  if (preg_match('/^image=on$/u', $_SERVER['QUERY_STRING'])){
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	  } elseif (isset($_GET['log']) && preg_match('/^log=(on|off)$/u', $_SERVER['QUERY_STRING'])){
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	  } elseif ($_SERVER["QUERY_STRING"] != ""){*/
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '&amp;image=off';
/*	  } else {
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	  }*/
	  echo '5.<a href="' . $self_anchor_invert_imagemode .  '" class="navigation-link" accesskey="5" rel="nofollow">画像省略</a> ';
  } else {
/*	  if (preg_match('/^image=off$/u', $_SERVER['QUERY_STRING'])){
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	  } elseif (isset($_GET['log']) && preg_match('/^log=(off|on)$/u', $_SERVER['QUERY_STRING'])){
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	  } elseif ($_SERVER["QUERY_STRING"] != ""){*/
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '&amp;image=on';
/*	  } else {
		  $self_anchor_invert_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	  }*/
	  echo '5.<a href="' . $self_anchor_invert_imagemode . '" class="navigation-link" accesskey="5" rel="nofollow">画像表示</a> ';
  }
} else {
  echo "5.&nbsp;-&nbsp;-&nbsp;-&nbsp;- ";
}
if ($navi_paging === TRUE){
  $next_url = htmlspecialchars($next_url, ENT_QUOTES);
  echo "6.<a href=\"{$next_url}\" class=\"navigation-link\" accesskey=\"6\" rel=\"nofollow\">次(p{$next_str})</a></li>";
} else {
  echo "6.&nbsp;-&nbsp;-&nbsp;-&nbsp;- </li>";
}
echo '<li>';
if (isset($entries_mode)){
  if ($entries_mode == 'keyword_timeline'){
// var_dump($entries_mode);
	echo "7.<a href=\"./keywords.php?related=".rawurlencode($_GET['keyword']);
	if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
	echo "\" class=\"navigation-link\" accesskey=\"7\">関連鍵語</a> ";
  } elseif ($entries_mode == 'user_timeline'){
	echo "7.<a href=\"./keywords.php?user=".$get_user;
	if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
	echo "\" class=\"navigation-link\" accesskey=\"7\">愛好鍵語</a> ";
  } elseif ($entries_mode == 'friends_timeline'){
	echo "7.<a href=\"./keywords.php?user=".$get_following;
	if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
	echo "\" class=\"navigation-link\" accesskey=\"7\">愛好鍵語</a> ";
  } else {
	echo '7.<a href="'.$to_keywords;
	if (isset($_GET['image']) && $_GET['image'] == 'on') echo '?image=on';
	echo "\" class=\"navigation-link\" accesskey=\"7\">鍵語一覧</a> ";
  }
} else {
  echo '7.<a href="'.$to_keywords;
  if (isset($_GET['image']) && $_GET['image'] == 'on') echo '?image=on';
  echo "\" class=\"navigation-link\" accesskey=\"7\">鍵語一覧</a> ";
}
if (isset($_SESSION['auth']) && $_SESSION['auth'] === TRUE){
	echo "8.<a href=\"./entries.php?following={$_SESSION['hatenaid']}";
	if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
	echo "\" class=\"navigation-link\" accesskey=\"8\">アンテナ</a> ";
} else {
	echo '8.&nbsp;-&nbsp;-&nbsp;-&nbsp;- ';
}
	echo '9.<a href="'.$to_index.'" class="navigation-link" accesskey="9">トビラ</a>';
echo '</li>';

/*echo '<li>';
if ($_SESSION['auth'] === TRUE){
	echo '[-]<a href="./login.php?log=out';
	if ($_SESSION['image'] == 'on') echo '&amp;image=on';
	echo '" class="navigation-link">ログアウト</a>';
} elseif ($_GET['image'] == 'on'){
	echo '[0]<a href="./login.php?return=' . rawurlencode($self_anchor_with_imagemode) . '&amp;image=on" class="navigation-link" accesskey="0">ログイン</a>';
} else {
	echo '[0]<a href="./login.php?return=' . rawurlencode($self_anchor_with_imagemode) . '" class="navigation-link" accesskey="0">ログイン</a>';
}
echo '</li>'."\n";*/
?>
</ul>
<hr />
<?php echo $footer; ?>
